import postcss from 'postcss';
import parser from 'postcss-selector-parser';

function process(root, is_global = false, prefix = null) {
	root.each(function (node) {
		if (!node.selector) {
			if (node.type === 'atrule') {
				if (/^(document|media|supports)$/.test(node.name)) {
					process(node, is_global, prefix);
				} else if (node.name === 'global') {
					if (is_global) {
						throw node.error("Can't nest @global and @cascade at-rules.");
					}
					process(node, true);
					node.replaceWith(node.nodes);
				} else if (node.name === 'cascade') {
					if (is_global) {
						throw node.error("Can't nest @global and @cascade at-rules.");
					}
					const prefix = parser().astSync(node.params + ' ');
					process(node, true, prefix);
					node.replaceWith(node.nodes);
				}
			}
		} else if (is_global) {
			node.selector = parser(function rewrite_selector_list(selectors) {
				selectors.each(function rewrite_complex_selector(complex_selector) {
					let skip = false;

					if (prefix) {
						complex_selector.prepend(prefix);
					}

					complex_selector.each(function rewrite_simple_selector(selector) {
						if (selector.type === 'combinator') {
							skip = false;
						}

						if (/^(id|class|attribute|tag|universal)$/.test(selector.type)) {
							if (!skip) {
								skip = true;

								const global = parser.pseudo({ value: ':global' });

								const clone = selector.clone();
								clone.spaces = { before: '', after: '' };

								global.append(clone);
								selector.replaceWith(global);
							}
						}
					});
				});
			}).processSync(node.selector);
		}
	});
}

var index = postcss.plugin('postcss-svelte-cascade', function (opts) {
	if (!opts) opts = {};

	return function walk(root) {
		process(root);
	}
});

export default index;
//# sourceMappingURL=index.mjs.map
